<?php

namespace Drupal\sucuri_cache\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Clears sucuri caches for a concrete page.
 *
 * @internal
 */
class PurgeEntityCacheForm extends ConfirmFormBase {

  /**
   * ID of the item to delete.
   *
   * @var int
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sucuri_cache__purge_entity_cache_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $node = NULL) {
    // @todo allow not only node.
    $this->entity = $node;
    return parent::buildForm($form, $form_state);
  }

  /**
   * Clears the caches.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // drupal_flush_all_caches();
    // @todo Do we need to flush Drupal Cache as well?
    $this->messenger()->addStatus($this->t('DRY RUN Caches cleared for %title.', [
      '%title' => $this->entity->label(),
    ]));
    // @todo add redirect back.
  }

  /**
   * Confirmation action.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   A string of question.
   */
  public function getQuestion() {
    return $this->t('Do you want to purge sucuri caches for %title?', [
      '%title' => $this->entity->label(),
    ]);
  }

  /**
   * Return URL for entity.
   *
   * @return \Drupal\Core\Url
   *   Url object.
   */
  public function getCancelUrl() {
    return $this->entity->toUrl('canonical');
  }

}
