<?php

namespace Drupal\sucuri_cache;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Service class responsible for cache purging.
 */
final class SucuriCachePurger {

  use StringTranslationTrait;

  const ACTION_CLEAR_CACHE = 'clear_cache';

  /**
   * API Client service.
   *
   * @var \Drupal\sucuri_cache\WafApiClient
   */
  private $apiClient;

  /**
   * Messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  private $messenger;

  /**
   * Constructs an SucuriCachePurger object.
   *
   * @param \Drupal\sucuri_cache\WafApiClient $api_client
   *   API Client.
   * @param \Drupal\sucuri_cache\SucuriCacheManager $manager
   *   Cache Manager.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Messenger Interface.
   */
  public function __construct(WafApiClient $api_client, SucuriCacheManager $manager, MessengerInterface $messenger) {
    $this->apiClient = $api_client;
    $this->messenger = $messenger;
  }

  /**
   * Cache clear for a specific entity.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   Entity object whose cache need to clear.
   *
   * @return bool
   *   Return Boolean.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function purgeCacheForEntity(EntityInterface $entity): bool {
    $res = $this->apiClient->requestAction(self::ACTION_CLEAR_CACHE, [
      'file' => $entity->toUrl()->toString(),
    ]);

    // @todo not sure about about success code here.
    if ($res->getStatusCode() === 200) {
      // Success.
      return TRUE;
    }
    return FALSE;
  }

}
